from pathlib import Path
import platform

__version__ = "0.5"

if platform.system() == 'Windows':
    LOGO = ":/images/icons/logo_small.png"
else:
    LOGO = (Path(__file__).parent.absolute() / "icons/logo.png").as_posix()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/javad/Current Works/github/Mine/negar-gui/negar_gui/hwin.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(205, 204)
        Dialog.setWindowTitle("")
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setText("")
        self.label.setTextFormat(QtCore.Qt.PlainText)
        self.label.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Close)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 1, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.buttonBox.accepted.connect(Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        pass


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog = QtWidgets.QDialog()
    ui = Ui_Dialog()
    ui.setupUi(Dialog)
    Dialog.show()
    sys.exit(app.exec_())



#!/usr/bin/env python

import sys
from pyuca import Collator
from pathlib import Path
from pyperclip import copy
from PyQt5.QtGui import QIcon, QColor
from PyQt5.QtCore import Qt, QAbstractTableModel, QSize
from PyQt5.QtWidgets import (QApplication, QMainWindow, QPushButton, QTableView, QHeaderView, QCheckBox,
                            QSlider, QLabel, QTextEdit, QLineEdit, QGroupBox, QGridLayout, QTabWidget,
                            QWidget, QHBoxLayout, QVBoxLayout, QFileDialog)
sys.path.append(Path(__file__).parent.parent.as_posix()) # https://stackoverflow.com/questions/16981921
from negar.virastar import PersianEditor, UnTouchable
from negar.constants import INFO
from negar_gui.constants import __version__, LOGO


collator = Collator()

class TableModel(QAbstractTableModel):
    def __init__(self, data):
        super(TableModel, self).__init__()
        self._data = data

    def data(self, index, role):
        if role == Qt.ItemDataRole.TextAlignmentRole:
            return Qt.AlignmentFlag.AlignVCenter
        if role == Qt.ItemDataRole.BackgroundRole:
            if index.row()%2:
                return QColor('gray')
        if role == Qt.ItemDataRole.ForegroundRole:
            if index.row()%2:
                return QColor('white')
        if role == Qt.ItemDataRole.DisplayRole:
            try:
                return self._data[index.row()][index.column()]
            except:
                return ''

    def rowCount(self, index):
        # The length of the outer list.
        return len(self._data)

    def columnCount(self, index):
        # The following takes the first sub-list, and returns
        # the length (only works if all rows are an equal length)
        return len(self._data[0])

    def headerData(self, section, orientation, role):
        # section is the index of the column/row.
        if role == Qt.ItemDataRole.DisplayRole:
            if orientation == Qt.Orientation.Horizontal:
                return ''
            if orientation == Qt.Orientation.Vertical:
                return str(section+1)

class Form(QMainWindow):
    def __init__(self, parent = None):
        super(Form, self).__init__(parent)
        self.editing_options = []

        self.table = QTableView(layoutDirection=Qt.LayoutDirection.RightToLeft,)
        self.setup_table()

        self.setupUi()

    def setup_table(self, col=8):
        self.table.horizontalHeader().setSectionResizeMode(QHeaderView.ResizeMode.Stretch)
        data = sorted(list(UnTouchable().get()), key=collator.sort_key)
        data = [data[i*col:(i+1)*col] for i in range(int(len(data)//col)+1)]
        model = TableModel(data)
        self.table.setModel(model)

    def setupUi(self):
        self.edit_btn = QPushButton(self.tr("&Edit"))
        self.edit_btn.setEnabled(False)
        reset_btn = QPushButton(self.tr("&Reset"))
        quit_btn = QPushButton(self.tr("&Quit"))
        import_btn = QPushButton(self.tr('Im&port'),)
        copy_btn = QPushButton(QIcon(LOGO), '',)
        copy_btn.setIconSize(QSize(24,24))
        copy_btn.setToolTip(self.tr("Click to Copy Sanitized Output"))
        copy_btn.setStyleSheet("QPushButton {border-style: outset; border-width: 0px;}")
        self.autoedit_chkbox = QCheckBox(self.tr("&Automatic edit"))
        self.autoedit_chkbox.setChecked(True)
        self.font_slider = QSlider(orientation=Qt.Orientation.Horizontal,
            minimum=10, maximum=40, value=18)
        font_slider_label = QLabel(self.tr("&Font Size"))
        font_slider_label.setBuddy(self.font_slider)

        btn_layout = QHBoxLayout()
        btn_layout.addWidget(self.autoedit_chkbox)
        btn_layout.addStretch()
        btn_layout.addWidget(font_slider_label)
        btn_layout.addWidget(self.font_slider)
        btn_layout.addStretch()
        btn_layout.addWidget(self.edit_btn)
        btn_layout.addWidget(reset_btn)
        btn_layout.addWidget(quit_btn)

        self.input_editor = QTextEdit()
        input_editor_label = QLabel(self.tr("&Input Box"))
        input_editor_label.setBuddy(self.input_editor)
        self.output_editor = QTextEdit()
        output_editor_label = QLabel(self.tr("&Output Box"))
        output_editor_label.setBuddy(self.output_editor)

        # Options:
        self.f_dashes = QCheckBox(self.tr("Fix &Dashes"), checked=True)
        self.f_three_dots = QCheckBox(self.tr("Fix &three dots"), checked=True)
        self.f_english_quotes = QCheckBox(self.tr("Fix English &quotes"), checked=True)
        self.f_hamzeh = QCheckBox(self.tr("Fix &hamzeh"), checked=True)
        self.hamzeh_yeh = QCheckBox(self.tr("Use 'Persian &yeh' to show hamzeh"), checked=True)
        self.f_spacing_bq = QCheckBox(self.tr("Fix &spacing braces and qoutes"), checked=True)
        self.f_arab_num = QCheckBox(self.tr("Fix Arabic &numbers"), checked=True)
        self.f_eng_num = QCheckBox(self.tr("Fix &English numbers"), checked=True)
        self.f_non_persian_ch = QCheckBox(self.tr("Fix non Persian &chars"), checked=True)
        self.f_p_spacing = QCheckBox(self.tr("Fix &prefix spacing"), checked=True)
        self.f_p_separate = QCheckBox(self.tr("Fix p&refix separating"), checked=True)
        self.f_s_spacing = QCheckBox(self.tr("Fix su&ffix spacing"), checked=True)
        self.f_s_separate = QCheckBox(self.tr("Fix s&uffix separating"), checked=True)
        self.aggressive = QCheckBox(self.tr("Fix a&ggressive punctuation"), checked=True)
        self.clnup_kashidas = QCheckBox(self.tr("Cleanup &kashidas"), checked=True)
        self.clnup_ex_marks = QCheckBox(self.tr("Cleanup e&xtra marks"), checked=True)
        self.clnup_spacing = QCheckBox(self.tr("C&leanup spacing"), checked=True)
        self.trim_lt_whitespaces = QCheckBox(self.tr("Tr&im Leading/Trailing Whitespaces"), checked=True)
        self.exaggeragin_zwnj = QCheckBox(self.tr("Exaggerating &ZWNJ"), checked=True)

        # Add to untouchable list:
        self.untouch_word = QLineEdit()
        untouch_label = QLabel(self.tr("Add a &word to untouchable list"))
        untouch_label.setBuddy(self.untouch_word)
        self.untouch_button = QPushButton(self.tr("&Add"), enabled=False)
        untouch_box = QGroupBox(self.tr("Untouchable words"))
        untouch_layout = QGridLayout()
        untouch_layout.addWidget(untouch_label, 0, 0)
        untouch_layout.addWidget(self.untouch_word, 1, 0)
        untouch_layout.addWidget(self.untouch_button, 1, 1)
        untouch_layout.addWidget(self.table, 2,0,1,2)
        untouch_box.setLayout(untouch_layout)

        # Options Box:
        config_box = QGroupBox(self.tr("Options"))
        config_layout = QGridLayout()
        config_layout.addWidget(self.f_dashes, 0, 0)
        config_layout.addWidget(self.f_three_dots, 1, 0)
        config_layout.addWidget(self.f_english_quotes, 0, 2)
        config_layout.addWidget(self.f_arab_num, 0, 1)
        config_layout.addWidget(self.f_eng_num, 1, 1)
        config_layout.addWidget(self.f_non_persian_ch, 1, 2)
        config_layout.addWidget(self.f_hamzeh, 2, 0)
        config_layout.addWidget(self.f_p_separate, 2, 1)
        config_layout.addWidget(self.f_s_separate, 2, 2)
        config_layout.addWidget(self.f_s_spacing, 3, 1)
        config_layout.addWidget(self.f_p_spacing, 3, 2)
        config_layout.addWidget(self.aggressive, 3, 3)
        config_layout.addWidget(self.exaggeragin_zwnj, 3, 5)
        config_layout.addWidget(self.f_spacing_bq, 0, 3, 1, 2)
        config_layout.addWidget(self.hamzeh_yeh, 1, 3, 1, 2)
        config_layout.addWidget(self.trim_lt_whitespaces, 2, 3, 1, 2)
        config_layout.addWidget(self.clnup_spacing, 0, 5)
        config_layout.addWidget(self.clnup_ex_marks, 1, 5)
        config_layout.addWidget(self.clnup_kashidas, 2, 5)
        config_box.setLayout(config_layout)

        # Tab widgets initializing:
        tab_widget = QTabWidget()
        main_tab = QWidget()
        config_tab = QWidget()

        # Config tab widgets layout:
        ct_layout = QVBoxLayout(config_tab)
        ct_layout.addWidget(config_box)
        ct_layout.addWidget(untouch_box)
        # ct_layout.addStretch()

        # layout for input_label + import button
        input_layout = QHBoxLayout()
        input_layout.addWidget(input_editor_label)
        input_layout.addStretch()
        input_layout.addWidget(import_btn)

        # layout for output_label + copy button
        output_layout = QHBoxLayout()
        output_layout.addWidget(output_editor_label)
        output_layout.addStretch()
        output_layout.addWidget(copy_btn)

        # Main Tab widgets layouts:
        mt_layout = QGridLayout(main_tab)
        mt_layout.addLayout(input_layout, 0, 0)
        mt_layout.addWidget(self.input_editor, 1, 0)
        mt_layout.addLayout(output_layout, 2,0)
        mt_layout.addWidget(self.output_editor, 3, 0)
        mt_layout.addLayout(btn_layout, 4, 0)

        # Main tab widget control:
        tab_widget.addTab(main_tab, self.tr("&Main"))
        tab_widget.addTab(config_tab, self.tr("&Config"))

        # Main window configs:
        self.setCentralWidget(tab_widget)
        self.resize(800, 600)
        self.setWindowIcon(QIcon(LOGO))
        self.setWindowTitle(self.tr(f"Negar {__version__}"))

        # Signal control:
        # first of all negar have to check the default state of automatic edit feature.
        self.autoedit_handler()
        quit_btn.clicked.connect(QApplication.instance().quit)
        reset_btn.clicked.connect(self.text_box_reset)
        self.edit_btn.clicked.connect(self.edit_text)

        import_btn.clicked.connect(self.file_dialog)
        copy_btn.clicked.connect(self.save_to_clipboard)
        # if autoedit_chkboxs state's changed, then autoedit_handler have to call again.
        self.autoedit_chkbox.stateChanged.connect(self.autoedit_handler)

        self.font_slider.valueChanged.connect(self._set_font_size)
        self.untouch_word.textChanged.connect(self.untouch_add_enabler)
        self.untouch_button.clicked.connect(self.untouch_add)

        # Option checkbox lists signal control
        self.f_dashes.stateChanged.connect(self.option_control)
        self.f_three_dots.stateChanged.connect(self.option_control)
        self.f_english_quotes.stateChanged.connect(self.option_control)
        self.f_hamzeh.stateChanged.connect(self.option_control)
        self.hamzeh_yeh.stateChanged.connect(self.option_control)
        self.f_spacing_bq.stateChanged.connect(self.option_control)
        self.f_arab_num.stateChanged.connect(self.option_control)
        self.f_eng_num.stateChanged.connect(self.option_control)
        self.f_non_persian_ch.stateChanged.connect(self.option_control)
        self.f_p_spacing.stateChanged.connect(self.option_control)
        self.f_p_separate.stateChanged.connect(self.option_control)
        self.f_s_spacing.stateChanged.connect(self.option_control)
        self.f_s_separate.stateChanged.connect(self.option_control)
        self.aggressive.stateChanged.connect(self.option_control)
        self.clnup_kashidas.stateChanged.connect(self.option_control)
        self.clnup_ex_marks.stateChanged.connect(self.option_control)
        self.clnup_spacing.stateChanged.connect(self.option_control)
        self.trim_lt_whitespaces.stateChanged.connect(self.option_control)
        self.exaggeragin_zwnj.stateChanged.connect(self.option_control)

    def keyPressEvent(self, event):
        if event.key() == Qt.Key.Key_Escape:
            self.save_to_clipboard()
            self.close()
        elif event.key() == Qt.Key.Key_F1:
            self.input_editor.clear()
            self.input_editor.setText(INFO)
        else:
            super().keyPressEvent(event)

    def _set_font_size(self,):
        size = self.font_slider.value()
        self.input_editor.setFontPointSize(size)
        self.output_editor.setFontPointSize(size)
        lines = self.input_editor.toPlainText()
        self.input_editor.clear()
        self.input_editor.append(lines)
        self.edit_text()

    def untouch_add_enabler(self):
        """Checks untouchable word text input to enable the `Add` button if just one word is typed."""
        word_list = self.untouch_word.text().split(" ")
        if len(word_list) == 1:
            self.untouch_button.setEnabled(True)
        else:
            self.untouch_button.setEnabled(False)

    def untouch_add(self):
        """Adds a new word into untouchable words"""
        word = [self.untouch_word.text()]
        UnTouchable.add(word)
        self.untouch_word.clear()
        self.edit_text()  # retouches the input text
        self.setup_table() # updates untouchable list

    def autoedit_handler(self):
        """Edits the input text automatically if `autoedit` is checked."""
        if self.autoedit_chkbox.isChecked():
            self.edit_btn.setEnabled(False)
            self.input_editor.textChanged.connect(self.edit_text)
        else:
            self.edit_btn.setEnabled(True)
            # This line will disconnect autoedit signal and will disable autoamtic edit option
            self.input_editor.textChanged.disconnect(self.edit_text)
        self._set_font_size()

    def text_box_reset(self):
        """Clears input/output editor boxes"""
        self.input_editor.clear()
        self.output_editor.clear()

    def option_control(self):
        """Enable/Disable Editing features"""
        if not self.f_dashes.isChecked():
            self.editing_options.append("fix-dashes")
        if not self.f_three_dots.isChecked():
            self.editing_options.append("fix-three-dots")
        if not self.f_english_quotes.isChecked():
            self.editing_options.append("fix-english-quotes")
        if not self.f_hamzeh.isChecked():
            self.editing_options.append("fix-hamzeh")
        if not self.hamzeh_yeh.isChecked():
            self.editing_options.append("hamzeh-with-yeh")
        if not self.f_spacing_bq.isChecked():
            self.editing_options.append("fix-spacing-bq")
        if not self.f_arab_num.isChecked():
            self.editing_options.append("fix-arabic-num")
        if not self.f_eng_num.isChecked():
            self.editing_options.append("fix-english-num")
        if not self.f_non_persian_ch.isChecked():
            self.editing_options.append("fix-non-persian-chars")
        if not self.f_p_spacing.isChecked():
            self.editing_options.append("fix-p-spacing")
        if not self.f_p_separate.isChecked():
            self.editing_options.append("fix-p-separate")
        if not self.f_s_spacing.isChecked():
            self.editing_options.append("fix-s-spacing")
        if not self.f_s_separate.isChecked():
            self.editing_options.append("fix-s-separate")
        if not self.aggressive.isChecked():
            self.editing_options.append("aggressive")
        if not self.clnup_kashidas.isChecked():
            self.editing_options.append("cleanup-kashidas")
        if not self.clnup_ex_marks.isChecked():
            self.editing_options.append("cleanup-ex-marks")
        if not self.clnup_spacing.isChecked():
            self.editing_options.append("cleanup-spacing")
        if not self.trim_lt_whitespaces.isChecked():
            self.editing_options.append("trim-lt-whitespaces")
        if not self.exaggeragin_zwnj.isChecked():
            self.editing_options.append("exaggerating-zwnj")

    def file_dialog(self):
        fname, _ = QFileDialog.getOpenFileName(self, 'Open File - A Plain Text')
        try:
            with open(fname, 'r', encoding="utf8") as f:
                self.input_editor.setText(f.read())
        except:
            pass

    def edit_text(self):
        self.output_editor.clear()
        run_PE = PersianEditor(self.input_editor.toPlainText(), *self.editing_options)
        self.output_editor.append(run_PE.cleanup())

    def save_to_clipboard(self):
        sanitizedText = self.output_editor.toPlainText()
        if sanitizedText:
            copy(sanitizedText)

def main():
    app = QApplication(sys.argv)
    run = Form()
    run.show()
    run.input_editor.setFocus() # set focus on input box
    sys.exit(app.exec())

if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'negar_gui/mwin.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1059, 790)
        MainWindow.setFocusPolicy(QtCore.Qt.StrongFocus)
        MainWindow.setLayoutDirection(QtCore.Qt.LeftToRight)
        MainWindow.setAutoFillBackground(False)
        MainWindow.setStyleSheet("QFrame {\n"
"    border: none;\n"
"    margin: 0px;\n"
"    padding: 0px;\n"
"}")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.centralwidget.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.centralwidget.setAutoFillBackground(True)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.frame_6 = QtWidgets.QFrame(self.centralwidget)
        self.frame_6.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setObjectName("frame_6")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame_6)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame = QtWidgets.QFrame(self.frame_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.frame)
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.frame_2 = QtWidgets.QFrame(self.frame)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.frame_2)
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_4.setSpacing(0)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.reset_btn = QtWidgets.QPushButton(self.frame_2)
        self.reset_btn.setStyleSheet("")
        self.reset_btn.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/images/icons/reset.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.reset_btn.setIcon(icon)
        self.reset_btn.setShortcut("")
        self.reset_btn.setObjectName("reset_btn")
        self.gridLayout_4.addWidget(self.reset_btn, 0, 0, 1, 1)
        self.copy_btn = QtWidgets.QPushButton(self.frame_2)
        self.copy_btn.setText("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/images/icons/copy.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.copy_btn.setIcon(icon1)
        self.copy_btn.setShortcut("")
        self.copy_btn.setObjectName("copy_btn")
        self.gridLayout_4.addWidget(self.copy_btn, 0, 1, 1, 1)
        self.paste_btn = QtWidgets.QPushButton(self.frame_2)
        self.paste_btn.setText("")
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/images/icons/paste.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.paste_btn.setIcon(icon2)
        self.paste_btn.setShortcut("")
        self.paste_btn.setObjectName("paste_btn")
        self.gridLayout_4.addWidget(self.paste_btn, 0, 2, 1, 1)
        self.qrcode_btn = QtWidgets.QPushButton(self.frame_2)
        self.qrcode_btn.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/images/icons/qr.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.qrcode_btn.setIcon(icon3)
        self.qrcode_btn.setShortcut("")
        self.qrcode_btn.setObjectName("qrcode_btn")
        self.gridLayout_4.addWidget(self.qrcode_btn, 0, 3, 1, 1)
        self.vertical_btn = QtWidgets.QPushButton(self.frame_2)
        self.vertical_btn.setText("")
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/images/icons/vertical.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.vertical_btn.setIcon(icon4)
        self.vertical_btn.setShortcut("")
        self.vertical_btn.setObjectName("vertical_btn")
        self.gridLayout_4.addWidget(self.vertical_btn, 0, 4, 1, 1)
        self.horizontal_btn = QtWidgets.QPushButton(self.frame_2)
        self.horizontal_btn.setText("")
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/images/icons/horizontal.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.horizontal_btn.setIcon(icon5)
        self.horizontal_btn.setShortcut("")
        self.horizontal_btn.setObjectName("horizontal_btn")
        self.gridLayout_4.addWidget(self.horizontal_btn, 0, 5, 1, 1)
        self.gridLayout_5.addWidget(self.frame_2, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(210, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(210, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem1, 0, 2, 1, 1)
        self.frame_4 = QtWidgets.QFrame(self.frame)
        self.frame_4.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_4.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_4.setObjectName("frame_4")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.frame_4)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_3.setVerticalSpacing(0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.font_slider_label = QtWidgets.QLabel(self.frame_4)
        self.font_slider_label.setObjectName("font_slider_label")
        self.gridLayout_3.addWidget(self.font_slider_label, 0, 0, 1, 1)
        self.font_slider = QtWidgets.QSlider(self.frame_4)
        self.font_slider.setMinimum(10)
        self.font_slider.setMaximum(72)
        self.font_slider.setProperty("value", 18)
        self.font_slider.setOrientation(QtCore.Qt.Horizontal)
        self.font_slider.setObjectName("font_slider")
        self.gridLayout_3.addWidget(self.font_slider, 0, 1, 1, 1)
        self.gridLayout_5.addWidget(self.frame_4, 0, 3, 1, 1)
        self.frame_3 = QtWidgets.QFrame(self.frame)
        self.frame_3.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_3.setObjectName("frame_3")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.frame_3)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_7.setVerticalSpacing(0)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.edit_btn = QtWidgets.QPushButton(self.frame_3)
        self.edit_btn.setEnabled(False)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/images/icons/edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.edit_btn.setIcon(icon6)
        self.edit_btn.setObjectName("edit_btn")
        self.gridLayout_7.addWidget(self.edit_btn, 0, 1, 1, 1)
        self.autoedit_chkbox = QtWidgets.QCheckBox(self.frame_3)
        self.autoedit_chkbox.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.autoedit_chkbox.setChecked(True)
        self.autoedit_chkbox.setObjectName("autoedit_chkbox")
        self.gridLayout_7.addWidget(self.autoedit_chkbox, 0, 0, 1, 1)
        self.gridLayout_5.addWidget(self.frame_3, 0, 4, 1, 1)
        self.verticalLayout.addWidget(self.frame)
        self.frame_5 = QtWidgets.QFrame(self.frame_6)
        self.frame_5.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_5.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_5.setObjectName("frame_5")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.frame_5)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.input_layout = QtWidgets.QGridLayout()
        self.input_layout.setObjectName("input_layout")
        self.input_editor_label = QtWidgets.QLabel(self.frame_5)
        self.input_editor_label.setObjectName("input_editor_label")
        self.input_layout.addWidget(self.input_editor_label, 0, 0, 1, 1)
        self.input_editor = QtWidgets.QTextEdit(self.frame_5)
        self.input_editor.setObjectName("input_editor")
        self.input_layout.addWidget(self.input_editor, 1, 0, 1, 1)
        self.gridLayout.addLayout(self.input_layout, 0, 0, 1, 1)
        self.output_editor_label = QtWidgets.QLabel(self.frame_5)
        self.output_editor_label.setObjectName("output_editor_label")
        self.gridLayout.addWidget(self.output_editor_label, 1, 0, 1, 1)
        self.output_editor = QtWidgets.QTextEdit(self.frame_5)
        self.output_editor.setObjectName("output_editor")
        self.gridLayout.addWidget(self.output_editor, 2, 0, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)
        self.verticalLayout.addWidget(self.frame_5)
        self.gridLayout_6.addWidget(self.frame_6, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1059, 27))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuSetting = QtWidgets.QMenu(self.menubar)
        self.menuSetting.setObjectName("menuSetting")
        self.menuOptions = QtWidgets.QMenu(self.menuSetting)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/images/icons/options.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuOptions.setIcon(icon7)
        self.menuOptions.setSeparatorsCollapsible(True)
        self.menuOptions.setObjectName("menuOptions")
        self.menuLanguage = QtWidgets.QMenu(self.menuSetting)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/images/icons/languages.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.menuLanguage.setIcon(icon8)
        self.menuLanguage.setObjectName("menuLanguage")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.menuHelp.sizePolicy().hasHeightForWidth())
        self.menuHelp.setSizePolicy(sizePolicy)
        self.menuHelp.setObjectName("menuHelp")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menu_View = QtWidgets.QMenu(self.menubar)
        self.menu_View.setObjectName("menu_View")
        MainWindow.setMenuBar(self.menubar)
        self.statusBar = QtWidgets.QStatusBar(MainWindow)
        self.statusBar.setObjectName("statusBar")
        MainWindow.setStatusBar(self.statusBar)
        self.actionOpen = QtWidgets.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/images/icons/open.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpen.setIcon(icon9)
        self.actionOpen.setShortcut("Ctrl+O")
        self.actionOpen.setObjectName("actionOpen")
        self.actionExport = QtWidgets.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/images/icons/export.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExport.setIcon(icon10)
        self.actionExport.setShortcut("Ctrl+E")
        self.actionExport.setObjectName("actionExport")
        self.actionExit = QtWidgets.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/images/icons/exit.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionExit.setIcon(icon11)
        self.actionExit.setShortcut("Ctrl+Q")
        self.actionExit.setObjectName("actionExit")
        self.actionAbout_Negar = QtWidgets.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/images/icons/about.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAbout_Negar.setIcon(icon12)
        self.actionAbout_Negar.setShortcut("")
        self.actionAbout_Negar.setObjectName("actionAbout_Negar")
        self.actionDonate = QtWidgets.QAction(MainWindow)
        self.actionDonate.setEnabled(False)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/images/icons/donate.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDonate.setIcon(icon13)
        self.actionDonate.setShortcut("")
        self.actionDonate.setObjectName("actionDonate")
        self.actionReport_Bugs = QtWidgets.QAction(MainWindow)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/images/icons/bugs.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionReport_Bugs.setIcon(icon14)
        self.actionReport_Bugs.setObjectName("actionReport_Bugs")
        self.actionNegar_Help = QtWidgets.QAction(MainWindow)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/images/icons/logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionNegar_Help.setIcon(icon15)
        self.actionNegar_Help.setShortcut("F1")
        self.actionNegar_Help.setObjectName("actionNegar_Help")
        self.actionFix_Dashes = QtWidgets.QAction(MainWindow)
        self.actionFix_Dashes.setCheckable(True)
        self.actionFix_Dashes.setChecked(True)
        self.actionFix_Dashes.setObjectName("actionFix_Dashes")
        self.actionFix_three_dots = QtWidgets.QAction(MainWindow)
        self.actionFix_three_dots.setCheckable(True)
        self.actionFix_three_dots.setChecked(True)
        self.actionFix_three_dots.setObjectName("actionFix_three_dots")
        self.actionFix_English_quotes = QtWidgets.QAction(MainWindow)
        self.actionFix_English_quotes.setCheckable(True)
        self.actionFix_English_quotes.setChecked(True)
        self.actionFix_English_quotes.setObjectName("actionFix_English_quotes")
        self.actionFix_hamzeh = QtWidgets.QAction(MainWindow)
        self.actionFix_hamzeh.setCheckable(True)
        self.actionFix_hamzeh.setChecked(True)
        self.actionFix_hamzeh.setObjectName("actionFix_hamzeh")
        self.actionUse_Persian_yeh_to_show_hamzeh = QtWidgets.QAction(MainWindow)
        self.actionUse_Persian_yeh_to_show_hamzeh.setCheckable(True)
        self.actionUse_Persian_yeh_to_show_hamzeh.setChecked(True)
        self.actionUse_Persian_yeh_to_show_hamzeh.setObjectName("actionUse_Persian_yeh_to_show_hamzeh")
        self.actionFix_spacing_braces_and_quotes = QtWidgets.QAction(MainWindow)
        self.actionFix_spacing_braces_and_quotes.setCheckable(True)
        self.actionFix_spacing_braces_and_quotes.setChecked(True)
        self.actionFix_spacing_braces_and_quotes.setObjectName("actionFix_spacing_braces_and_quotes")
        self.actionFix_Arabic_numbers = QtWidgets.QAction(MainWindow)
        self.actionFix_Arabic_numbers.setCheckable(True)
        self.actionFix_Arabic_numbers.setChecked(True)
        self.actionFix_Arabic_numbers.setObjectName("actionFix_Arabic_numbers")
        self.actionFix_English_numbers = QtWidgets.QAction(MainWindow)
        self.actionFix_English_numbers.setCheckable(True)
        self.actionFix_English_numbers.setChecked(True)
        self.actionFix_English_numbers.setObjectName("actionFix_English_numbers")
        self.actionFix_non_Persian_chars = QtWidgets.QAction(MainWindow)
        self.actionFix_non_Persian_chars.setCheckable(True)
        self.actionFix_non_Persian_chars.setChecked(True)
        self.actionFix_non_Persian_chars.setObjectName("actionFix_non_Persian_chars")
        self.actionFix_prefix_spacing = QtWidgets.QAction(MainWindow)
        self.actionFix_prefix_spacing.setCheckable(True)
        self.actionFix_prefix_spacing.setChecked(True)
        self.actionFix_prefix_spacing.setObjectName("actionFix_prefix_spacing")
        self.actionFix_prefix_separating = QtWidgets.QAction(MainWindow)
        self.actionFix_prefix_separating.setCheckable(True)
        self.actionFix_prefix_separating.setChecked(True)
        self.actionFix_prefix_separating.setObjectName("actionFix_prefix_separating")
        self.actionFix_suffix_spacing = QtWidgets.QAction(MainWindow)
        self.actionFix_suffix_spacing.setCheckable(True)
        self.actionFix_suffix_spacing.setChecked(True)
        self.actionFix_suffix_spacing.setObjectName("actionFix_suffix_spacing")
        self.actionFix_suffix_separating = QtWidgets.QAction(MainWindow)
        self.actionFix_suffix_separating.setCheckable(True)
        self.actionFix_suffix_separating.setChecked(True)
        self.actionFix_suffix_separating.setObjectName("actionFix_suffix_separating")
        self.actionFix_aggressive_punctuation = QtWidgets.QAction(MainWindow)
        self.actionFix_aggressive_punctuation.setCheckable(True)
        self.actionFix_aggressive_punctuation.setChecked(True)
        self.actionFix_aggressive_punctuation.setObjectName("actionFix_aggressive_punctuation")
        self.actionCleanup_kashidas = QtWidgets.QAction(MainWindow)
        self.actionCleanup_kashidas.setCheckable(True)
        self.actionCleanup_kashidas.setChecked(True)
        self.actionCleanup_kashidas.setObjectName("actionCleanup_kashidas")
        self.actionCleanup_extra_marks = QtWidgets.QAction(MainWindow)
        self.actionCleanup_extra_marks.setCheckable(True)
        self.actionCleanup_extra_marks.setChecked(True)
        self.actionCleanup_extra_marks.setObjectName("actionCleanup_extra_marks")
        self.actionCleanup_spacing = QtWidgets.QAction(MainWindow)
        self.actionCleanup_spacing.setCheckable(True)
        self.actionCleanup_spacing.setChecked(True)
        self.actionCleanup_spacing.setObjectName("actionCleanup_spacing")
        self.actionTrim_Leading_Trailing_Whitespaces = QtWidgets.QAction(MainWindow)
        self.actionTrim_Leading_Trailing_Whitespaces.setCheckable(True)
        self.actionTrim_Leading_Trailing_Whitespaces.setChecked(True)
        self.actionTrim_Leading_Trailing_Whitespaces.setObjectName("actionTrim_Leading_Trailing_Whitespaces")
        self.actionExaggerating_ZWNJ = QtWidgets.QAction(MainWindow)
        self.actionExaggerating_ZWNJ.setCheckable(True)
        self.actionExaggerating_ZWNJ.setChecked(True)
        self.actionExaggerating_ZWNJ.setObjectName("actionExaggerating_ZWNJ")
        self.actionUntouchable_Words = QtWidgets.QAction(MainWindow)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/images/icons/words.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionUntouchable_Words.setIcon(icon16)
        self.actionUntouchable_Words.setShortcut("")
        self.actionUntouchable_Words.setObjectName("actionUntouchable_Words")
        self.actionPersian = QtWidgets.QAction(MainWindow)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/images/icons/Fa.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPersian.setIcon(icon17)
        self.actionPersian.setShortcut("Ctrl+L, Ctrl+F")
        self.actionPersian.setObjectName("actionPersian")
        self.actionEnglish = QtWidgets.QAction(MainWindow)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/images/icons/En.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionEnglish.setIcon(icon18)
        self.actionEnglish.setShortcut("Ctrl+L, Ctrl+E")
        self.actionEnglish.setObjectName("actionEnglish")
        self.actionCopy = QtWidgets.QAction(MainWindow)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(":/images/icons/copy.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionCopy.setIcon(icon19)
        self.actionCopy.setShortcut("Ctrl+C")
        self.actionCopy.setObjectName("actionCopy")
        self.actionPaste = QtWidgets.QAction(MainWindow)
        self.actionPaste.setIcon(icon2)
        self.actionPaste.setShortcut("Ctrl+V")
        self.actionPaste.setObjectName("actionPaste")
        self.actionIncrease_Font_Size = QtWidgets.QAction(MainWindow)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(":/images/icons/increase.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionIncrease_Font_Size.setIcon(icon20)
        self.actionIncrease_Font_Size.setShortcut("Ctrl+=")
        self.actionIncrease_Font_Size.setObjectName("actionIncrease_Font_Size")
        self.actionDecrease_Font_Size = QtWidgets.QAction(MainWindow)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(":/images/icons/decrease.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDecrease_Font_Size.setIcon(icon21)
        self.actionDecrease_Font_Size.setShortcut("Ctrl+-")
        self.actionDecrease_Font_Size.setObjectName("actionDecrease_Font_Size")
        self.actionReset = QtWidgets.QAction(MainWindow)
        self.actionReset.setIcon(icon)
        self.actionReset.setShortcut("Ctrl+R")
        self.actionReset.setObjectName("actionReset")
        self.actionSide_by_Side_View = QtWidgets.QAction(MainWindow)
        self.actionSide_by_Side_View.setCheckable(True)
        self.actionSide_by_Side_View.setShortcut("Ctrl+S")
        self.actionSide_by_Side_View.setObjectName("actionSide_by_Side_View")
        self.actionAbout_Negar_GUI = QtWidgets.QAction(MainWindow)
        self.actionAbout_Negar_GUI.setObjectName("actionAbout_Negar_GUI")
        self.actionInteractive_Clipboard = QtWidgets.QAction(MainWindow)
        self.actionInteractive_Clipboard.setCheckable(True)
        self.actionInteractive_Clipboard.setShortcut("Ctrl+I")
        self.actionInteractive_Clipboard.setObjectName("actionInteractive_Clipboard")
        self.actionUpdate = QtWidgets.QAction(MainWindow)
        self.actionUpdate.setObjectName("actionUpdate")
        self.actionQr_Code = QtWidgets.QAction(MainWindow)
        self.actionQr_Code.setIcon(icon3)
        self.actionQr_Code.setObjectName("actionQr_Code")
        self.actionFull_Screen_Input = QtWidgets.QAction(MainWindow)
        self.actionFull_Screen_Input.setCheckable(True)
        self.actionFull_Screen_Input.setObjectName("actionFull_Screen_Input")
        self.action_Dark_Mode = QtWidgets.QAction(MainWindow)
        self.action_Dark_Mode.setCheckable(True)
        self.action_Dark_Mode.setEnabled(False)
        self.action_Dark_Mode.setObjectName("action_Dark_Mode")
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionExport)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuOptions.addAction(self.actionFix_Dashes)
        self.menuOptions.addAction(self.actionFix_three_dots)
        self.menuOptions.addAction(self.actionFix_English_quotes)
        self.menuOptions.addAction(self.actionFix_hamzeh)
        self.menuOptions.addAction(self.actionFix_spacing_braces_and_quotes)
        self.menuOptions.addAction(self.actionFix_Arabic_numbers)
        self.menuOptions.addAction(self.actionFix_English_numbers)
        self.menuOptions.addAction(self.actionFix_non_Persian_chars)
        self.menuOptions.addAction(self.actionFix_prefix_spacing)
        self.menuOptions.addAction(self.actionFix_prefix_separating)
        self.menuOptions.addAction(self.actionFix_suffix_spacing)
        self.menuOptions.addAction(self.actionFix_suffix_separating)
        self.menuOptions.addAction(self.actionFix_aggressive_punctuation)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionUse_Persian_yeh_to_show_hamzeh)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionCleanup_spacing)
        self.menuOptions.addAction(self.actionCleanup_kashidas)
        self.menuOptions.addAction(self.actionCleanup_extra_marks)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionExaggerating_ZWNJ)
        self.menuOptions.addAction(self.actionTrim_Leading_Trailing_Whitespaces)
        self.menuLanguage.addAction(self.actionPersian)
        self.menuLanguage.addAction(self.actionEnglish)
        self.menuSetting.addAction(self.menuOptions.menuAction())
        self.menuSetting.addAction(self.actionInteractive_Clipboard)
        self.menuSetting.addAction(self.menuLanguage.menuAction())
        self.menuSetting.addSeparator()
        self.menuSetting.addAction(self.actionUntouchable_Words)
        self.menuHelp.addAction(self.actionNegar_Help)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout_Negar)
        self.menuHelp.addAction(self.actionAbout_Negar_GUI)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionDonate)
        self.menuHelp.addAction(self.actionReport_Bugs)
        self.menuEdit.addAction(self.actionCopy)
        self.menuEdit.addAction(self.actionPaste)
        self.menuEdit.addAction(self.actionReset)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionQr_Code)
        self.menu_View.addAction(self.actionIncrease_Font_Size)
        self.menu_View.addAction(self.actionDecrease_Font_Size)
        self.menu_View.addSeparator()
        self.menu_View.addAction(self.actionSide_by_Side_View)
        self.menu_View.addAction(self.actionFull_Screen_Input)
        self.menu_View.addAction(self.action_Dark_Mode)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menu_View.menuAction())
        self.menubar.addAction(self.menuSetting.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.font_slider_label.setBuddy(self.font_slider)
        self.input_editor_label.setBuddy(self.input_editor)
        self.output_editor_label.setBuddy(self.output_editor)

        self.retranslateUi(MainWindow)
        self.actionExit.triggered.connect(MainWindow.close) # type: ignore
        self.autoedit_chkbox.toggled['bool'].connect(self.edit_btn.setDisabled) # type: ignore
        self.reset_btn.clicked.connect(self.input_editor.clear) # type: ignore
        self.reset_btn.clicked.connect(self.output_editor.clear) # type: ignore
        self.actionPaste.triggered.connect(self.input_editor.paste) # type: ignore
        self.actionCopy.triggered.connect(self.output_editor.copy) # type: ignore
        self.actionIncrease_Font_Size.triggered.connect(self.input_editor.zoomIn) # type: ignore
        self.actionIncrease_Font_Size.triggered.connect(self.output_editor.zoomIn) # type: ignore
        self.actionDecrease_Font_Size.triggered.connect(self.output_editor.zoomOut) # type: ignore
        self.actionDecrease_Font_Size.triggered.connect(self.input_editor.zoomOut) # type: ignore
        self.actionReset.triggered.connect(self.reset_btn.click) # type: ignore
        self.paste_btn.clicked.connect(self.input_editor.paste) # type: ignore
        self.qrcode_btn.clicked['bool'].connect(self.actionQr_Code.trigger) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.input_editor, self.output_editor)
        MainWindow.setTabOrder(self.output_editor, self.reset_btn)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "Negar"))
        self.reset_btn.setToolTip(_translate("MainWindow", "Reset Ctrl+R"))
        self.copy_btn.setToolTip(_translate("MainWindow", "Copy Ctrl+C"))
        self.paste_btn.setToolTip(_translate("MainWindow", "Paste Ctrl+V"))
        self.qrcode_btn.setToolTip(_translate("MainWindow", "QR code"))
        self.vertical_btn.setToolTip(_translate("MainWindow", "vertical view"))
        self.horizontal_btn.setToolTip(_translate("MainWindow", "horizontal view"))
        self.font_slider_label.setText(_translate("MainWindow", "&Font Size"))
        self.edit_btn.setText(_translate("MainWindow", "E&dit"))
        self.autoedit_chkbox.setText(_translate("MainWindow", "Real-&time Edit"))
        self.input_editor_label.setText(_translate("MainWindow", "&Original:"))
        self.output_editor_label.setText(_translate("MainWindow", "Re&vision:"))
        self.menuFile.setTitle(_translate("MainWindow", "&File"))
        self.menuSetting.setTitle(_translate("MainWindow", "&Settings"))
        self.menuOptions.setTitle(_translate("MainWindow", "Editing &Options"))
        self.menuLanguage.setTitle(_translate("MainWindow", "&Language"))
        self.menuHelp.setTitle(_translate("MainWindow", "&Help"))
        self.menuEdit.setTitle(_translate("MainWindow", "&Edit"))
        self.menu_View.setTitle(_translate("MainWindow", "&View"))
        self.actionOpen.setText(_translate("MainWindow", "&Open"))
        self.actionExport.setText(_translate("MainWindow", "&Export"))
        self.actionExit.setText(_translate("MainWindow", "E&xit"))
        self.actionAbout_Negar.setText(_translate("MainWindow", "&About Negar"))
        self.actionDonate.setText(_translate("MainWindow", "&Donate"))
        self.actionReport_Bugs.setText(_translate("MainWindow", "&Report Bugs"))
        self.actionNegar_Help.setText(_translate("MainWindow", "Negar &Help"))
        self.actionFix_Dashes.setText(_translate("MainWindow", "Fix &Dashes"))
        self.actionFix_three_dots.setText(_translate("MainWindow", "Fix &three dots"))
        self.actionFix_English_quotes.setText(_translate("MainWindow", "Fix English &quotes"))
        self.actionFix_hamzeh.setText(_translate("MainWindow", "Fix &hamzeh"))
        self.actionUse_Persian_yeh_to_show_hamzeh.setText(_translate("MainWindow", "Use \'Persian &yeh\' to show hamzeh"))
        self.actionFix_spacing_braces_and_quotes.setText(_translate("MainWindow", "Fix &spacing braces and quotes"))
        self.actionFix_Arabic_numbers.setText(_translate("MainWindow", "Fix Arabic &numbers"))
        self.actionFix_English_numbers.setText(_translate("MainWindow", "Fix &English numbers"))
        self.actionFix_non_Persian_chars.setText(_translate("MainWindow", "Fix non Persian &chars"))
        self.actionFix_prefix_spacing.setText(_translate("MainWindow", "Fix &prefix spacing"))
        self.actionFix_prefix_separating.setText(_translate("MainWindow", "Fix p&refix separating"))
        self.actionFix_suffix_spacing.setText(_translate("MainWindow", "Fix su&ffix spacing"))
        self.actionFix_suffix_separating.setText(_translate("MainWindow", "Fix s&uffix separating"))
        self.actionFix_aggressive_punctuation.setText(_translate("MainWindow", "Fix a&ggressive punctuation"))
        self.actionCleanup_kashidas.setText(_translate("MainWindow", "Cleanup &kashidas"))
        self.actionCleanup_extra_marks.setText(_translate("MainWindow", "Cleanup e&xtra marks"))
        self.actionCleanup_spacing.setText(_translate("MainWindow", "C&leanup spacing"))
        self.actionTrim_Leading_Trailing_Whitespaces.setText(_translate("MainWindow", "Tr&im Leading/Trailing Whitespaces"))
        self.actionExaggerating_ZWNJ.setText(_translate("MainWindow", "Exaggerating &ZWNJ"))
        self.actionUntouchable_Words.setText(_translate("MainWindow", "&Untouchable Words"))
        self.actionPersian.setText(_translate("MainWindow", "&Persian"))
        self.actionEnglish.setText(_translate("MainWindow", "&English"))
        self.actionCopy.setText(_translate("MainWindow", "&Copy"))
        self.actionPaste.setText(_translate("MainWindow", "&Paste"))
        self.actionIncrease_Font_Size.setText(_translate("MainWindow", "&Increase Font Size"))
        self.actionDecrease_Font_Size.setText(_translate("MainWindow", "&Decrease Font Size"))
        self.actionReset.setText(_translate("MainWindow", "&Reset"))
        self.actionSide_by_Side_View.setText(_translate("MainWindow", "&Side-by-Side View"))
        self.actionAbout_Negar_GUI.setText(_translate("MainWindow", "About &Negar-GUI"))
        self.actionInteractive_Clipboard.setText(_translate("MainWindow", "&Interactive Clipboard"))
        self.actionUpdate.setText(_translate("MainWindow", "Update Check"))
        self.actionQr_Code.setText(_translate("MainWindow", "&QR Code"))
        self.actionFull_Screen_Input.setText(_translate("MainWindow", "&Full Screen Input"))
        self.actionFull_Screen_Input.setShortcut(_translate("MainWindow", "Ctrl+F"))
        self.action_Dark_Mode.setText(_translate("MainWindow", "&Dark Mode"))
        self.action_Dark_Mode.setShortcut(_translate("MainWindow", "Ctrl+D"))
from . import resource_rc


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'mwin.ui'
##
## Created by: Qt User Interface Compiler version 6.2.4
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide6.QtCore import (QCoreApplication, QDate, QDateTime, QLocale,
    QMetaObject, QObject, QPoint, QRect,
    QSize, QTime, QUrl, Qt)
from PySide6.QtGui import (QAction, QBrush, QColor, QConicalGradient,
    QCursor, QFont, QFontDatabase, QGradient,
    QIcon, QImage, QKeySequence, QLinearGradient,
    QPainter, QPalette, QPixmap, QRadialGradient,
    QTransform)
from PySide6.QtWidgets import (QApplication, QCheckBox, QFrame, QGridLayout,
    QLabel, QMainWindow, QMenu, QMenuBar,
    QPushButton, QSizePolicy, QSlider, QSpacerItem,
    QStatusBar, QTextEdit, QVBoxLayout, QWidget)
import resource_rc

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(1059, 790)
        MainWindow.setFocusPolicy(Qt.StrongFocus)
        MainWindow.setLayoutDirection(Qt.LeftToRight)
        MainWindow.setAutoFillBackground(False)
        MainWindow.setStyleSheet(u"QFrame {\n"
"	border: none;\n"
"	margin: 0px;\n"
"	padding: 0px;\n"
"}")
        self.actionOpen = QAction(MainWindow)
        self.actionOpen.setObjectName(u"actionOpen")
        icon = QIcon()
        icon.addFile(u":/images/icons/open.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionOpen.setIcon(icon)
#if QT_CONFIG(shortcut)
        self.actionOpen.setShortcut(u"Ctrl+O")
#endif // QT_CONFIG(shortcut)
        self.actionExport = QAction(MainWindow)
        self.actionExport.setObjectName(u"actionExport")
        icon1 = QIcon()
        icon1.addFile(u":/images/icons/export.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionExport.setIcon(icon1)
#if QT_CONFIG(shortcut)
        self.actionExport.setShortcut(u"Ctrl+E")
#endif // QT_CONFIG(shortcut)
        self.actionExit = QAction(MainWindow)
        self.actionExit.setObjectName(u"actionExit")
        icon2 = QIcon()
        icon2.addFile(u":/images/icons/exit.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionExit.setIcon(icon2)
#if QT_CONFIG(shortcut)
        self.actionExit.setShortcut(u"Ctrl+Q")
#endif // QT_CONFIG(shortcut)
        self.actionAbout_Negar = QAction(MainWindow)
        self.actionAbout_Negar.setObjectName(u"actionAbout_Negar")
        icon3 = QIcon()
        icon3.addFile(u":/images/icons/about.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionAbout_Negar.setIcon(icon3)
#if QT_CONFIG(shortcut)
        self.actionAbout_Negar.setShortcut(u"")
#endif // QT_CONFIG(shortcut)
        self.actionDonate = QAction(MainWindow)
        self.actionDonate.setObjectName(u"actionDonate")
        self.actionDonate.setEnabled(False)
        icon4 = QIcon()
        icon4.addFile(u":/images/icons/donate.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionDonate.setIcon(icon4)
#if QT_CONFIG(shortcut)
        self.actionDonate.setShortcut(u"")
#endif // QT_CONFIG(shortcut)
        self.actionReport_Bugs = QAction(MainWindow)
        self.actionReport_Bugs.setObjectName(u"actionReport_Bugs")
        icon5 = QIcon()
        icon5.addFile(u":/images/icons/bugs.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionReport_Bugs.setIcon(icon5)
        self.actionNegar_Help = QAction(MainWindow)
        self.actionNegar_Help.setObjectName(u"actionNegar_Help")
        icon6 = QIcon()
        icon6.addFile(u":/images/icons/logo.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionNegar_Help.setIcon(icon6)
#if QT_CONFIG(shortcut)
        self.actionNegar_Help.setShortcut(u"F1")
#endif // QT_CONFIG(shortcut)
        self.actionFix_Dashes = QAction(MainWindow)
        self.actionFix_Dashes.setObjectName(u"actionFix_Dashes")
        self.actionFix_Dashes.setCheckable(True)
        self.actionFix_Dashes.setChecked(True)
        self.actionFix_three_dots = QAction(MainWindow)
        self.actionFix_three_dots.setObjectName(u"actionFix_three_dots")
        self.actionFix_three_dots.setCheckable(True)
        self.actionFix_three_dots.setChecked(True)
        self.actionFix_English_quotes = QAction(MainWindow)
        self.actionFix_English_quotes.setObjectName(u"actionFix_English_quotes")
        self.actionFix_English_quotes.setCheckable(True)
        self.actionFix_English_quotes.setChecked(True)
        self.actionFix_hamzeh = QAction(MainWindow)
        self.actionFix_hamzeh.setObjectName(u"actionFix_hamzeh")
        self.actionFix_hamzeh.setCheckable(True)
        self.actionFix_hamzeh.setChecked(True)
        self.actionUse_Persian_yeh_to_show_hamzeh = QAction(MainWindow)
        self.actionUse_Persian_yeh_to_show_hamzeh.setObjectName(u"actionUse_Persian_yeh_to_show_hamzeh")
        self.actionUse_Persian_yeh_to_show_hamzeh.setCheckable(True)
        self.actionUse_Persian_yeh_to_show_hamzeh.setChecked(True)
        self.actionFix_spacing_braces_and_quotes = QAction(MainWindow)
        self.actionFix_spacing_braces_and_quotes.setObjectName(u"actionFix_spacing_braces_and_quotes")
        self.actionFix_spacing_braces_and_quotes.setCheckable(True)
        self.actionFix_spacing_braces_and_quotes.setChecked(True)
        self.actionFix_Arabic_numbers = QAction(MainWindow)
        self.actionFix_Arabic_numbers.setObjectName(u"actionFix_Arabic_numbers")
        self.actionFix_Arabic_numbers.setCheckable(True)
        self.actionFix_Arabic_numbers.setChecked(True)
        self.actionFix_English_numbers = QAction(MainWindow)
        self.actionFix_English_numbers.setObjectName(u"actionFix_English_numbers")
        self.actionFix_English_numbers.setCheckable(True)
        self.actionFix_English_numbers.setChecked(True)
        self.actionFix_non_Persian_chars = QAction(MainWindow)
        self.actionFix_non_Persian_chars.setObjectName(u"actionFix_non_Persian_chars")
        self.actionFix_non_Persian_chars.setCheckable(True)
        self.actionFix_non_Persian_chars.setChecked(True)
        self.actionFix_prefix_spacing = QAction(MainWindow)
        self.actionFix_prefix_spacing.setObjectName(u"actionFix_prefix_spacing")
        self.actionFix_prefix_spacing.setCheckable(True)
        self.actionFix_prefix_spacing.setChecked(True)
        self.actionFix_prefix_separating = QAction(MainWindow)
        self.actionFix_prefix_separating.setObjectName(u"actionFix_prefix_separating")
        self.actionFix_prefix_separating.setCheckable(True)
        self.actionFix_prefix_separating.setChecked(True)
        self.actionFix_suffix_spacing = QAction(MainWindow)
        self.actionFix_suffix_spacing.setObjectName(u"actionFix_suffix_spacing")
        self.actionFix_suffix_spacing.setCheckable(True)
        self.actionFix_suffix_spacing.setChecked(True)
        self.actionFix_suffix_separating = QAction(MainWindow)
        self.actionFix_suffix_separating.setObjectName(u"actionFix_suffix_separating")
        self.actionFix_suffix_separating.setCheckable(True)
        self.actionFix_suffix_separating.setChecked(True)
        self.actionFix_aggressive_punctuation = QAction(MainWindow)
        self.actionFix_aggressive_punctuation.setObjectName(u"actionFix_aggressive_punctuation")
        self.actionFix_aggressive_punctuation.setCheckable(True)
        self.actionFix_aggressive_punctuation.setChecked(True)
        self.actionCleanup_kashidas = QAction(MainWindow)
        self.actionCleanup_kashidas.setObjectName(u"actionCleanup_kashidas")
        self.actionCleanup_kashidas.setCheckable(True)
        self.actionCleanup_kashidas.setChecked(True)
        self.actionCleanup_extra_marks = QAction(MainWindow)
        self.actionCleanup_extra_marks.setObjectName(u"actionCleanup_extra_marks")
        self.actionCleanup_extra_marks.setCheckable(True)
        self.actionCleanup_extra_marks.setChecked(True)
        self.actionCleanup_spacing = QAction(MainWindow)
        self.actionCleanup_spacing.setObjectName(u"actionCleanup_spacing")
        self.actionCleanup_spacing.setCheckable(True)
        self.actionCleanup_spacing.setChecked(True)
        self.actionTrim_Leading_Trailing_Whitespaces = QAction(MainWindow)
        self.actionTrim_Leading_Trailing_Whitespaces.setObjectName(u"actionTrim_Leading_Trailing_Whitespaces")
        self.actionTrim_Leading_Trailing_Whitespaces.setCheckable(True)
        self.actionTrim_Leading_Trailing_Whitespaces.setChecked(True)
        self.actionExaggerating_ZWNJ = QAction(MainWindow)
        self.actionExaggerating_ZWNJ.setObjectName(u"actionExaggerating_ZWNJ")
        self.actionExaggerating_ZWNJ.setCheckable(True)
        self.actionExaggerating_ZWNJ.setChecked(True)
        self.actionUntouchable_Words = QAction(MainWindow)
        self.actionUntouchable_Words.setObjectName(u"actionUntouchable_Words")
        icon7 = QIcon()
        icon7.addFile(u":/images/icons/words.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionUntouchable_Words.setIcon(icon7)
#if QT_CONFIG(shortcut)
        self.actionUntouchable_Words.setShortcut(u"")
#endif // QT_CONFIG(shortcut)
        self.actionPersian = QAction(MainWindow)
        self.actionPersian.setObjectName(u"actionPersian")
        icon8 = QIcon()
        icon8.addFile(u":/images/icons/Fa.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionPersian.setIcon(icon8)
#if QT_CONFIG(shortcut)
        self.actionPersian.setShortcut(u"Ctrl+L, Ctrl+F")
#endif // QT_CONFIG(shortcut)
        self.actionEnglish = QAction(MainWindow)
        self.actionEnglish.setObjectName(u"actionEnglish")
        icon9 = QIcon()
        icon9.addFile(u":/images/icons/En.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionEnglish.setIcon(icon9)
#if QT_CONFIG(shortcut)
        self.actionEnglish.setShortcut(u"Ctrl+L, Ctrl+E")
#endif // QT_CONFIG(shortcut)
        self.actionCopy = QAction(MainWindow)
        self.actionCopy.setObjectName(u"actionCopy")
        icon10 = QIcon()
        icon10.addFile(u":/images/icons/copy.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionCopy.setIcon(icon10)
#if QT_CONFIG(shortcut)
        self.actionCopy.setShortcut(u"Ctrl+C")
#endif // QT_CONFIG(shortcut)
        self.actionPaste = QAction(MainWindow)
        self.actionPaste.setObjectName(u"actionPaste")
        icon11 = QIcon()
        icon11.addFile(u":/images/icons/paste.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionPaste.setIcon(icon11)
#if QT_CONFIG(shortcut)
        self.actionPaste.setShortcut(u"Ctrl+V")
#endif // QT_CONFIG(shortcut)
        self.actionIncrease_Font_Size = QAction(MainWindow)
        self.actionIncrease_Font_Size.setObjectName(u"actionIncrease_Font_Size")
        icon12 = QIcon()
        icon12.addFile(u":/images/icons/increase.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionIncrease_Font_Size.setIcon(icon12)
#if QT_CONFIG(shortcut)
        self.actionIncrease_Font_Size.setShortcut(u"Ctrl+=")
#endif // QT_CONFIG(shortcut)
        self.actionDecrease_Font_Size = QAction(MainWindow)
        self.actionDecrease_Font_Size.setObjectName(u"actionDecrease_Font_Size")
        icon13 = QIcon()
        icon13.addFile(u":/images/icons/decrease.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.actionDecrease_Font_Size.setIcon(icon13)
#if QT_CONFIG(shortcut)
        self.actionDecrease_Font_Size.setShortcut(u"Ctrl+-")
#endif // QT_CONFIG(shortcut)
        self.actionReset = QAction(MainWindow)
        self.actionReset.setObjectName(u"actionReset")
        icon14 = QIcon()
        icon14.addFile(u":/images/icons/reset.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionReset.setIcon(icon14)
#if QT_CONFIG(shortcut)
        self.actionReset.setShortcut(u"Ctrl+R")
#endif // QT_CONFIG(shortcut)
        self.actionSide_by_Side_View = QAction(MainWindow)
        self.actionSide_by_Side_View.setObjectName(u"actionSide_by_Side_View")
        self.actionSide_by_Side_View.setCheckable(True)
#if QT_CONFIG(shortcut)
        self.actionSide_by_Side_View.setShortcut(u"Ctrl+S")
#endif // QT_CONFIG(shortcut)
        self.actionAbout_Negar_GUI = QAction(MainWindow)
        self.actionAbout_Negar_GUI.setObjectName(u"actionAbout_Negar_GUI")
        self.actionInteractive_Clipboard = QAction(MainWindow)
        self.actionInteractive_Clipboard.setObjectName(u"actionInteractive_Clipboard")
        self.actionInteractive_Clipboard.setCheckable(True)
#if QT_CONFIG(shortcut)
        self.actionInteractive_Clipboard.setShortcut(u"Ctrl+I")
#endif // QT_CONFIG(shortcut)
        self.actionUpdate = QAction(MainWindow)
        self.actionUpdate.setObjectName(u"actionUpdate")
        self.actionQr_Code = QAction(MainWindow)
        self.actionQr_Code.setObjectName(u"actionQr_Code")
        icon15 = QIcon()
        icon15.addFile(u":/images/icons/qr.png", QSize(), QIcon.Normal, QIcon.Off)
        self.actionQr_Code.setIcon(icon15)
        self.actionFull_Screen_Input = QAction(MainWindow)
        self.actionFull_Screen_Input.setObjectName(u"actionFull_Screen_Input")
        self.actionFull_Screen_Input.setCheckable(True)
        self.action_Dark_Mode = QAction(MainWindow)
        self.action_Dark_Mode.setObjectName(u"action_Dark_Mode")
        self.action_Dark_Mode.setCheckable(True)
        self.action_Dark_Mode.setEnabled(False)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.centralwidget.setEnabled(True)
        sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setFocusPolicy(Qt.StrongFocus)
        self.centralwidget.setLayoutDirection(Qt.LeftToRight)
        self.centralwidget.setAutoFillBackground(True)
        self.gridLayout_6 = QGridLayout(self.centralwidget)
        self.gridLayout_6.setObjectName(u"gridLayout_6")
        self.frame_6 = QFrame(self.centralwidget)
        self.frame_6.setObjectName(u"frame_6")
        self.frame_6.setFrameShape(QFrame.StyledPanel)
        self.frame_6.setFrameShadow(QFrame.Raised)
        self.verticalLayout = QVBoxLayout(self.frame_6)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.frame = QFrame(self.frame_6)
        self.frame.setObjectName(u"frame")
        sizePolicy1 = QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy1)
        self.frame.setFrameShape(QFrame.StyledPanel)
        self.frame.setFrameShadow(QFrame.Raised)
        self.gridLayout_5 = QGridLayout(self.frame)
        self.gridLayout_5.setObjectName(u"gridLayout_5")
        self.gridLayout_5.setContentsMargins(0, 0, 0, 0)
        self.frame_2 = QFrame(self.frame)
        self.frame_2.setObjectName(u"frame_2")
        self.frame_2.setFrameShape(QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QFrame.Raised)
        self.gridLayout_4 = QGridLayout(self.frame_2)
        self.gridLayout_4.setSpacing(0)
        self.gridLayout_4.setObjectName(u"gridLayout_4")
        self.gridLayout_4.setContentsMargins(0, 0, 0, 0)
        self.reset_btn = QPushButton(self.frame_2)
        self.reset_btn.setObjectName(u"reset_btn")
        self.reset_btn.setStyleSheet(u"")
        self.reset_btn.setIcon(icon14)
#if QT_CONFIG(shortcut)
        self.reset_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.reset_btn, 0, 0, 1, 1)

        self.copy_btn = QPushButton(self.frame_2)
        self.copy_btn.setObjectName(u"copy_btn")
        icon16 = QIcon()
        icon16.addFile(u":/images/icons/copy.png", QSize(), QIcon.Normal, QIcon.Off)
        self.copy_btn.setIcon(icon16)
#if QT_CONFIG(shortcut)
        self.copy_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.copy_btn, 0, 1, 1, 1)

        self.paste_btn = QPushButton(self.frame_2)
        self.paste_btn.setObjectName(u"paste_btn")
        self.paste_btn.setIcon(icon11)
#if QT_CONFIG(shortcut)
        self.paste_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.paste_btn, 0, 2, 1, 1)

        self.qrcode_btn = QPushButton(self.frame_2)
        self.qrcode_btn.setObjectName(u"qrcode_btn")
        self.qrcode_btn.setIcon(icon15)
#if QT_CONFIG(shortcut)
        self.qrcode_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.qrcode_btn, 0, 3, 1, 1)

        self.vertical_btn = QPushButton(self.frame_2)
        self.vertical_btn.setObjectName(u"vertical_btn")
        icon17 = QIcon()
        icon17.addFile(u":/images/icons/vertical.png", QSize(), QIcon.Normal, QIcon.Off)
        self.vertical_btn.setIcon(icon17)
#if QT_CONFIG(shortcut)
        self.vertical_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.vertical_btn, 0, 4, 1, 1)

        self.horizontal_btn = QPushButton(self.frame_2)
        self.horizontal_btn.setObjectName(u"horizontal_btn")
        icon18 = QIcon()
        icon18.addFile(u":/images/icons/horizontal.png", QSize(), QIcon.Normal, QIcon.Off)
        self.horizontal_btn.setIcon(icon18)
#if QT_CONFIG(shortcut)
        self.horizontal_btn.setShortcut(u"")
#endif // QT_CONFIG(shortcut)

        self.gridLayout_4.addWidget(self.horizontal_btn, 0, 5, 1, 1)


        self.gridLayout_5.addWidget(self.frame_2, 0, 0, 1, 1)

        self.horizontalSpacer = QSpacerItem(210, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_5.addItem(self.horizontalSpacer, 0, 1, 1, 1)

        self.horizontalSpacer_2 = QSpacerItem(210, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_5.addItem(self.horizontalSpacer_2, 0, 2, 1, 1)

        self.frame_4 = QFrame(self.frame)
        self.frame_4.setObjectName(u"frame_4")
        self.frame_4.setFrameShape(QFrame.StyledPanel)
        self.frame_4.setFrameShadow(QFrame.Raised)
        self.gridLayout_3 = QGridLayout(self.frame_4)
        self.gridLayout_3.setObjectName(u"gridLayout_3")
        self.gridLayout_3.setVerticalSpacing(0)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.font_slider_label = QLabel(self.frame_4)
        self.font_slider_label.setObjectName(u"font_slider_label")

        self.gridLayout_3.addWidget(self.font_slider_label, 0, 0, 1, 1)

        self.font_slider = QSlider(self.frame_4)
        self.font_slider.setObjectName(u"font_slider")
        self.font_slider.setMinimum(10)
        self.font_slider.setMaximum(72)
        self.font_slider.setValue(18)
        self.font_slider.setOrientation(Qt.Horizontal)

        self.gridLayout_3.addWidget(self.font_slider, 0, 1, 1, 1)


        self.gridLayout_5.addWidget(self.frame_4, 0, 3, 1, 1)

        self.frame_3 = QFrame(self.frame)
        self.frame_3.setObjectName(u"frame_3")
        self.frame_3.setFrameShape(QFrame.StyledPanel)
        self.frame_3.setFrameShadow(QFrame.Raised)
        self.gridLayout_7 = QGridLayout(self.frame_3)
        self.gridLayout_7.setObjectName(u"gridLayout_7")
        self.gridLayout_7.setVerticalSpacing(0)
        self.gridLayout_7.setContentsMargins(0, 0, 0, 0)
        self.edit_btn = QPushButton(self.frame_3)
        self.edit_btn.setObjectName(u"edit_btn")
        self.edit_btn.setEnabled(False)
        icon19 = QIcon()
        icon19.addFile(u":/images/icons/edit.png", QSize(), QIcon.Normal, QIcon.Off)
        self.edit_btn.setIcon(icon19)

        self.gridLayout_7.addWidget(self.edit_btn, 0, 1, 1, 1)

        self.autoedit_chkbox = QCheckBox(self.frame_3)
        self.autoedit_chkbox.setObjectName(u"autoedit_chkbox")
        self.autoedit_chkbox.setLayoutDirection(Qt.RightToLeft)
        self.autoedit_chkbox.setChecked(True)

        self.gridLayout_7.addWidget(self.autoedit_chkbox, 0, 0, 1, 1)


        self.gridLayout_5.addWidget(self.frame_3, 0, 4, 1, 1)


        self.verticalLayout.addWidget(self.frame)

        self.frame_5 = QFrame(self.frame_6)
        self.frame_5.setObjectName(u"frame_5")
        self.frame_5.setFrameShape(QFrame.StyledPanel)
        self.frame_5.setFrameShadow(QFrame.Raised)
        self.gridLayout_2 = QGridLayout(self.frame_5)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setObjectName(u"gridLayout_2")
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout = QGridLayout()
        self.gridLayout.setObjectName(u"gridLayout")
        self.input_layout = QGridLayout()
        self.input_layout.setObjectName(u"input_layout")
        self.input_editor_label = QLabel(self.frame_5)
        self.input_editor_label.setObjectName(u"input_editor_label")

        self.input_layout.addWidget(self.input_editor_label, 0, 0, 1, 1)

        self.input_editor = QTextEdit(self.frame_5)
        self.input_editor.setObjectName(u"input_editor")

        self.input_layout.addWidget(self.input_editor, 1, 0, 1, 1)


        self.gridLayout.addLayout(self.input_layout, 0, 0, 1, 1)

        self.output_editor_label = QLabel(self.frame_5)
        self.output_editor_label.setObjectName(u"output_editor_label")

        self.gridLayout.addWidget(self.output_editor_label, 1, 0, 1, 1)

        self.output_editor = QTextEdit(self.frame_5)
        self.output_editor.setObjectName(u"output_editor")

        self.gridLayout.addWidget(self.output_editor, 2, 0, 1, 1)


        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)


        self.verticalLayout.addWidget(self.frame_5)


        self.gridLayout_6.addWidget(self.frame_6, 0, 0, 1, 1)

        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 1059, 27))
        self.menuFile = QMenu(self.menubar)
        self.menuFile.setObjectName(u"menuFile")
        self.menuSetting = QMenu(self.menubar)
        self.menuSetting.setObjectName(u"menuSetting")
        self.menuOptions = QMenu(self.menuSetting)
        self.menuOptions.setObjectName(u"menuOptions")
        icon20 = QIcon()
        icon20.addFile(u":/images/icons/options.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.menuOptions.setIcon(icon20)
        self.menuOptions.setSeparatorsCollapsible(True)
        self.menuLanguage = QMenu(self.menuSetting)
        self.menuLanguage.setObjectName(u"menuLanguage")
        icon21 = QIcon()
        icon21.addFile(u":/images/icons/languages.svg", QSize(), QIcon.Normal, QIcon.Off)
        self.menuLanguage.setIcon(icon21)
        self.menuHelp = QMenu(self.menubar)
        self.menuHelp.setObjectName(u"menuHelp")
        sizePolicy2 = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.menuHelp.sizePolicy().hasHeightForWidth())
        self.menuHelp.setSizePolicy(sizePolicy2)
        self.menuEdit = QMenu(self.menubar)
        self.menuEdit.setObjectName(u"menuEdit")
        self.menu_View = QMenu(self.menubar)
        self.menu_View.setObjectName(u"menu_View")
        MainWindow.setMenuBar(self.menubar)
        self.statusBar = QStatusBar(MainWindow)
        self.statusBar.setObjectName(u"statusBar")
        MainWindow.setStatusBar(self.statusBar)
#if QT_CONFIG(shortcut)
        self.font_slider_label.setBuddy(self.font_slider)
        self.input_editor_label.setBuddy(self.input_editor)
        self.output_editor_label.setBuddy(self.output_editor)
#endif // QT_CONFIG(shortcut)
        QWidget.setTabOrder(self.input_editor, self.output_editor)
        QWidget.setTabOrder(self.output_editor, self.reset_btn)

        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menu_View.menuAction())
        self.menubar.addAction(self.menuSetting.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionExport)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuSetting.addAction(self.menuOptions.menuAction())
        self.menuSetting.addAction(self.actionInteractive_Clipboard)
        self.menuSetting.addAction(self.menuLanguage.menuAction())
        self.menuSetting.addSeparator()
        self.menuSetting.addAction(self.actionUntouchable_Words)
        self.menuOptions.addAction(self.actionFix_Dashes)
        self.menuOptions.addAction(self.actionFix_three_dots)
        self.menuOptions.addAction(self.actionFix_English_quotes)
        self.menuOptions.addAction(self.actionFix_hamzeh)
        self.menuOptions.addAction(self.actionFix_spacing_braces_and_quotes)
        self.menuOptions.addAction(self.actionFix_Arabic_numbers)
        self.menuOptions.addAction(self.actionFix_English_numbers)
        self.menuOptions.addAction(self.actionFix_non_Persian_chars)
        self.menuOptions.addAction(self.actionFix_prefix_spacing)
        self.menuOptions.addAction(self.actionFix_prefix_separating)
        self.menuOptions.addAction(self.actionFix_suffix_spacing)
        self.menuOptions.addAction(self.actionFix_suffix_separating)
        self.menuOptions.addAction(self.actionFix_aggressive_punctuation)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionUse_Persian_yeh_to_show_hamzeh)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionCleanup_spacing)
        self.menuOptions.addAction(self.actionCleanup_kashidas)
        self.menuOptions.addAction(self.actionCleanup_extra_marks)
        self.menuOptions.addSeparator()
        self.menuOptions.addAction(self.actionExaggerating_ZWNJ)
        self.menuOptions.addAction(self.actionTrim_Leading_Trailing_Whitespaces)
        self.menuLanguage.addAction(self.actionPersian)
        self.menuLanguage.addAction(self.actionEnglish)
        self.menuHelp.addAction(self.actionNegar_Help)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionAbout_Negar)
        self.menuHelp.addAction(self.actionAbout_Negar_GUI)
        self.menuHelp.addSeparator()
        self.menuHelp.addAction(self.actionDonate)
        self.menuHelp.addAction(self.actionReport_Bugs)
        self.menuEdit.addAction(self.actionCopy)
        self.menuEdit.addAction(self.actionPaste)
        self.menuEdit.addAction(self.actionReset)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionQr_Code)
        self.menu_View.addAction(self.actionIncrease_Font_Size)
        self.menu_View.addAction(self.actionDecrease_Font_Size)
        self.menu_View.addSeparator()
        self.menu_View.addAction(self.actionSide_by_Side_View)
        self.menu_View.addAction(self.actionFull_Screen_Input)
        self.menu_View.addAction(self.action_Dark_Mode)

        self.retranslateUi(MainWindow)
        self.actionExit.triggered.connect(MainWindow.close)
        self.autoedit_chkbox.toggled.connect(self.edit_btn.setDisabled)
        self.reset_btn.clicked.connect(self.input_editor.clear)
        self.reset_btn.clicked.connect(self.output_editor.clear)
        self.actionPaste.triggered.connect(self.input_editor.paste)
        self.actionCopy.triggered.connect(self.output_editor.copy)
        self.actionIncrease_Font_Size.triggered.connect(self.input_editor.zoomIn)
        self.actionIncrease_Font_Size.triggered.connect(self.output_editor.zoomIn)
        self.actionDecrease_Font_Size.triggered.connect(self.output_editor.zoomOut)
        self.actionDecrease_Font_Size.triggered.connect(self.input_editor.zoomOut)
        self.actionReset.triggered.connect(self.reset_btn.click)
        self.paste_btn.clicked.connect(self.input_editor.paste)
        self.qrcode_btn.clicked["bool"].connect(self.actionQr_Code.trigger)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"Negar", None))
        self.actionOpen.setText(QCoreApplication.translate("MainWindow", u"&Open", None))
        self.actionExport.setText(QCoreApplication.translate("MainWindow", u"&Export", None))
        self.actionExit.setText(QCoreApplication.translate("MainWindow", u"E&xit", None))
        self.actionAbout_Negar.setText(QCoreApplication.translate("MainWindow", u"&About Negar", None))
        self.actionDonate.setText(QCoreApplication.translate("MainWindow", u"&Donate", None))
        self.actionReport_Bugs.setText(QCoreApplication.translate("MainWindow", u"&Report Bugs", None))
        self.actionNegar_Help.setText(QCoreApplication.translate("MainWindow", u"Negar &Help", None))
        self.actionFix_Dashes.setText(QCoreApplication.translate("MainWindow", u"Fix &Dashes", None))
        self.actionFix_three_dots.setText(QCoreApplication.translate("MainWindow", u"Fix &three dots", None))
        self.actionFix_English_quotes.setText(QCoreApplication.translate("MainWindow", u"Fix English &quotes", None))
        self.actionFix_hamzeh.setText(QCoreApplication.translate("MainWindow", u"Fix &hamzeh", None))
        self.actionUse_Persian_yeh_to_show_hamzeh.setText(QCoreApplication.translate("MainWindow", u"Use 'Persian &yeh' to show hamzeh", None))
        self.actionFix_spacing_braces_and_quotes.setText(QCoreApplication.translate("MainWindow", u"Fix &spacing braces and quotes", None))
        self.actionFix_Arabic_numbers.setText(QCoreApplication.translate("MainWindow", u"Fix Arabic &numbers", None))
        self.actionFix_English_numbers.setText(QCoreApplication.translate("MainWindow", u"Fix &English numbers", None))
        self.actionFix_non_Persian_chars.setText(QCoreApplication.translate("MainWindow", u"Fix non Persian &chars", None))
        self.actionFix_prefix_spacing.setText(QCoreApplication.translate("MainWindow", u"Fix &prefix spacing", None))
        self.actionFix_prefix_separating.setText(QCoreApplication.translate("MainWindow", u"Fix p&refix separating", None))
        self.actionFix_suffix_spacing.setText(QCoreApplication.translate("MainWindow", u"Fix su&ffix spacing", None))
        self.actionFix_suffix_separating.setText(QCoreApplication.translate("MainWindow", u"Fix s&uffix separating", None))
        self.actionFix_aggressive_punctuation.setText(QCoreApplication.translate("MainWindow", u"Fix a&ggressive punctuation", None))
        self.actionCleanup_kashidas.setText(QCoreApplication.translate("MainWindow", u"Cleanup &kashidas", None))
        self.actionCleanup_extra_marks.setText(QCoreApplication.translate("MainWindow", u"Cleanup e&xtra marks", None))
        self.actionCleanup_spacing.setText(QCoreApplication.translate("MainWindow", u"C&leanup spacing", None))
        self.actionTrim_Leading_Trailing_Whitespaces.setText(QCoreApplication.translate("MainWindow", u"Tr&im Leading/Trailing Whitespaces", None))
        self.actionExaggerating_ZWNJ.setText(QCoreApplication.translate("MainWindow", u"Exaggerating &ZWNJ", None))
        self.actionUntouchable_Words.setText(QCoreApplication.translate("MainWindow", u"&Untouchable Words", None))
        self.actionPersian.setText(QCoreApplication.translate("MainWindow", u"&Persian", None))
        self.actionEnglish.setText(QCoreApplication.translate("MainWindow", u"&English", None))
        self.actionCopy.setText(QCoreApplication.translate("MainWindow", u"&Copy", None))
        self.actionPaste.setText(QCoreApplication.translate("MainWindow", u"&Paste", None))
        self.actionIncrease_Font_Size.setText(QCoreApplication.translate("MainWindow", u"&Increase Font Size", None))
        self.actionDecrease_Font_Size.setText(QCoreApplication.translate("MainWindow", u"&Decrease Font Size", None))
        self.actionReset.setText(QCoreApplication.translate("MainWindow", u"&Reset", None))
        self.actionSide_by_Side_View.setText(QCoreApplication.translate("MainWindow", u"&Side-by-Side View", None))
        self.actionAbout_Negar_GUI.setText(QCoreApplication.translate("MainWindow", u"About &Negar-GUI", None))
        self.actionInteractive_Clipboard.setText(QCoreApplication.translate("MainWindow", u"&Interactive Clipboard", None))
        self.actionUpdate.setText(QCoreApplication.translate("MainWindow", u"Update Check", None))
        self.actionQr_Code.setText(QCoreApplication.translate("MainWindow", u"&QR Code", None))
        self.actionFull_Screen_Input.setText(QCoreApplication.translate("MainWindow", u"&Full Screen Input", None))
#if QT_CONFIG(shortcut)
        self.actionFull_Screen_Input.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+F", None))
#endif // QT_CONFIG(shortcut)
        self.action_Dark_Mode.setText(QCoreApplication.translate("MainWindow", u"&Dark Mode", None))
#if QT_CONFIG(shortcut)
        self.action_Dark_Mode.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+D", None))
#endif // QT_CONFIG(shortcut)
#if QT_CONFIG(tooltip)
        self.reset_btn.setToolTip(QCoreApplication.translate("MainWindow", u"Reset Ctrl+R", None))
#endif // QT_CONFIG(tooltip)
        self.reset_btn.setText("")
#if QT_CONFIG(tooltip)
        self.copy_btn.setToolTip(QCoreApplication.translate("MainWindow", u"Copy Ctrl+C", None))
#endif // QT_CONFIG(tooltip)
        self.copy_btn.setText("")
#if QT_CONFIG(tooltip)
        self.paste_btn.setToolTip(QCoreApplication.translate("MainWindow", u"Paste Ctrl+V", None))
#endif // QT_CONFIG(tooltip)
        self.paste_btn.setText("")
#if QT_CONFIG(tooltip)
        self.qrcode_btn.setToolTip(QCoreApplication.translate("MainWindow", u"QR code", None))
#endif // QT_CONFIG(tooltip)
        self.qrcode_btn.setText("")
#if QT_CONFIG(tooltip)
        self.vertical_btn.setToolTip(QCoreApplication.translate("MainWindow", u"vertical view", None))
#endif // QT_CONFIG(tooltip)
        self.vertical_btn.setText("")
#if QT_CONFIG(tooltip)
        self.horizontal_btn.setToolTip(QCoreApplication.translate("MainWindow", u"horizontal view", None))
#endif // QT_CONFIG(tooltip)
        self.horizontal_btn.setText("")
        self.font_slider_label.setText(QCoreApplication.translate("MainWindow", u"&Font Size", None))
        self.edit_btn.setText(QCoreApplication.translate("MainWindow", u"E&dit", None))
        self.autoedit_chkbox.setText(QCoreApplication.translate("MainWindow", u"Real-&time Edit", None))
        self.input_editor_label.setText(QCoreApplication.translate("MainWindow", u"&Original:", None))
        self.output_editor_label.setText(QCoreApplication.translate("MainWindow", u"Re&vision:", None))
        self.menuFile.setTitle(QCoreApplication.translate("MainWindow", u"&File", None))
        self.menuSetting.setTitle(QCoreApplication.translate("MainWindow", u"&Settings", None))
        self.menuOptions.setTitle(QCoreApplication.translate("MainWindow", u"Editing &Options", None))
        self.menuLanguage.setTitle(QCoreApplication.translate("MainWindow", u"&Language", None))
        self.menuHelp.setTitle(QCoreApplication.translate("MainWindow", u"&Help", None))
        self.menuEdit.setTitle(QCoreApplication.translate("MainWindow", u"&Edit", None))
        self.menu_View.setTitle(QCoreApplication.translate("MainWindow", u"&View", None))
    # retranslateUi

